@@ -6,7 +6,7 @@
 //#![forbid(clippy::cognitive_complexity)]
 #![forbid(unreachable_pub)]
 #![forbid(elided_lifetimes_in_paths)]
-#![doc(html_root_url = "https://docs.rs/fend-core/0.1.19")]
+#![doc(html_root_url = "https://docs.rs/fend-core/0.1.20")]
 
 mod ast;
 mod date;
@@ -110,12 +110,19 @@ struct CurrentTimeInfo {
     timezone_offset_secs: i64,
 }
 
+#[derive(Clone, Debug, PartialEq, Eq)]
+enum FCMode {
+    CelsiusFahrenheit,
+    CoulombFarad,
+}
+
 /// This struct contains context used for `fend`. It should only be created once
 /// at startup.
 #[derive(Clone, Debug)]
 pub struct Context {
     current_time: Option<CurrentTimeInfo>,
     variables: HashMap<String, value::Value>,
+    fc_mode: FCMode,
 }
 
 impl Default for Context {
@@ -132,6 +139,7 @@ impl Context {
         Self {
             current_time: None,
             variables: HashMap::new(),
+            fc_mode: FCMode::CelsiusFahrenheit,
         }
     }
 
@@ -152,6 +160,12 @@ impl Context {
         // });
         self.current_time = None;
     }
+
+    /// Define the units `C` and `F` as coulomb and farad instead of degrees
+    /// celsius and degrees fahrenheit.
+    pub fn use_coulomb_and_farad(&mut self) {
+        self.fc_mode = FCMode::CoulombFarad;
+    }
 }
 
 /// This function evaluates a string using the given context. Any evaluation using this
@@ -203,7 +217,7 @@ pub fn evaluate_with_interrupt(
 }
 
 const fn get_version_as_str() -> &'static str {
-    "0.1.19"
+    "0.1.20"
 }
 
 /// Returns the current version of `fend-core`.
