@@ -39,12 +39,12 @@ const BASE_UNIT_ABBREVIATIONS: &[UnitTuple] = &[
 const TEMPERATURE_SCALES: &[UnitTuple] = &[
     ("celsius", "", "l@!", ""),
     ("\u{b0}C", "", "celsius", ""), // degree symbol
-    ("C", "", "=\u{b0}C", ""),
+    ("oC", "", "=\u{b0}C", ""),
     ("rankine", "", "l@5/9 K", ""),
     ("\u{b0}R", "", "rankine", ""),
     ("fahrenheit", "", "l@!", ""),
     ("\u{b0}F", "", "fahrenheit", ""),
-    ("F", "", "=\u{b0}F", ""),
+    ("oF", "", "=\u{b0}F", ""),
 ];
 
 const BITS_AND_BYTES: &[UnitTuple] = &[
@@ -292,15 +292,20 @@ const COMMON_SI_DERIVED_UNITS: &[UnitTuple] = &[
     ("J", "", "s@joule", ""),
     ("watt", "watts", "l@J/s", "power"),
     ("W", "", "s@watt", ""),
+    (
+        "horsepower",
+        "horsepowers",
+        "l@745.699987158227022 watts",
+        "",
+    ),
+    ("hp", "", "s@horsepower", ""),
     ("coulomb", "", "l@A s", "charge"),
-    ("C", "", "s@coulomb", ""),
     ("volt", "volts", "l@W/A", "potential difference"),
     ("V", "", "s@volt", ""),
     ("ohm", "ohms", "l@V/A", "electrical resistance"),
     ("siemens", "", "l@A/V", "electrical conductance"),
     ("S", "", "s@siemens", ""),
-    ("farad", "", "l@C/V", "capacitance"),
-    ("F", "", "s@farad", ""),
+    ("farad", "", "l@coulomb/V", "capacitance"),
     ("weber", "", "l@V s", "magnetic flux"),
     ("Wb", "", "s@weber", ""),
     ("henry", "", "l@V s / A", "inductance"),
@@ -311,6 +316,35 @@ const COMMON_SI_DERIVED_UNITS: &[UnitTuple] = &[
     ("Hz", "", "s@hertz", ""),
     ("nit", "nits", "l@candela / meter^2", "luminance"),
     ("nt", "", "nit", ""),
+    ("lumen", "lumens", "l@cd sr", "luminous flux"),
+    ("lm", "", "s@lumen", ""),
+    ("lx", "lux", "l@lm/m^2", "illuminance"),
+    ("phot", "phots", "l@1e4 lx", ""),
+    ("ph", "", "s@phot", ""),
+    ("becquerel", "becquerels", "l@/s", "radioactivity"),
+    ("Bq", "", "s@becquerel", ""),
+    ("curie", "curies", "l@3.7e10 Bq", ""),
+    ("Ci", "", "s@curie", ""),
+    ("rutherford", "rutherfords", "l@1e6 Bq", ""),
+    ("Rd", "", "s@rutherford", ""),
+    (
+        "gray",
+        "grays",
+        "l@J/kg",
+        "absorbed dose of ionising radiation",
+    ),
+    ("Gy", "", "s@gray", ""),
+    ("rad", "", "l@1/100 Gy", ""),
+    (
+        "sievert",
+        "sieverts",
+        "l@J / kg",
+        "equivalent dose of ionising radiation",
+    ),
+    ("Sv", "", "s@sievert", ""),
+    ("rem", "", "l@1/100 Sv", ""),
+    ("roentgen", "roentgens", "l@0.000258 coulomb/kg", ""),
+    ("R", "", "s@roentgen", ""),
 ];
 
 const TIME_UNITS: &[UnitTuple] = &[
@@ -427,6 +461,9 @@ const COMMON_PHYSICAL_UNITS: &[UnitTuple] = &[
     ("bicron", "bicrons", "l@picometer", ""),
     ("gsm", "", "grams / meter^2", ""),
     ("hectare", "hectares", "hectoare", ""),
+    ("ha", "", "s@hectare", ""),
+    ("decare", "decares", "l@decaare", ""),
+    ("da", "", "s@decare", ""),
     ("calorie", "calories", "l@4.184 J", ""),
     ("cal", "", "s@calorie", ""),
     (
