@@ -5267,6 +5267,14 @@ fn binary_modulo() {
     test_eval("0b1001010 mod 5", "0b100");
 }
 
+#[test]
+fn huge_modulo() {
+    test_eval(
+        "9283749283460298374027364928736492873469287354267354 mod 4",
+        "2",
+    );
+}
+
 #[test]
 fn month_of_date() {
     test_eval_simple("month of ('2020-03-04' to date)", "March");
@@ -5345,3 +5353,26 @@ fn multiple_variables() {
 fn mixed_frac() {
     test_eval_simple("4/3 to mixed_frac", "1 1/3");
 }
+
+#[test]
+fn farad_conversion() {
+    test_eval("1 farad to A^2 kg^-1 m^-2 s^4", "1 A^2 s^4 kg^-1 m^-2");
+}
+
+#[test]
+fn coulomb_farad_mode() {
+    let mut ctx = Context::new();
+    ctx.use_coulomb_and_farad();
+    assert_eq!(
+        evaluate("5C to coulomb", &mut ctx)
+            .unwrap()
+            .get_main_result(),
+        "5 coulomb"
+    );
+    assert_eq!(
+        evaluate("5uF to farad", &mut ctx)
+            .unwrap()
+            .get_main_result(),
+        "0.000005 farad"
+    );
+}
